@@ -3,11 +3,6 @@ package fi.csc.chipster.tools.ngs;
 import java.io.File;
 import java.io.IOException;
 
-import fi.csc.chipster.tools.gbrowser.ChromosomeNormaliser;
-import fi.csc.chipster.tools.gbrowser.SamBamUtils;
-import fi.csc.chipster.tools.gbrowser.TsvSorter;
-import fi.csc.chipster.tools.gbrowser.SamBamUtils.SamBamUtilState;
-import fi.csc.chipster.tools.gbrowser.SamBamUtils.SamBamUtilStateListener;
 import fi.csc.microarray.client.Session;
 import fi.csc.microarray.client.operation.Operation;
 import fi.csc.microarray.client.operation.OperationRecord;
@@ -15,6 +10,11 @@ import fi.csc.microarray.client.tasks.Task;
 import fi.csc.microarray.client.visualisation.methods.gbrowser.fileFormat.BEDParser;
 import fi.csc.microarray.client.visualisation.methods.gbrowser.fileFormat.ElandParser;
 import fi.csc.microarray.client.visualisation.methods.gbrowser.fileFormat.TsvParser;
+import fi.csc.microarray.client.visualisation.methods.gbrowser.util.ChromosomeNormaliser;
+import fi.csc.microarray.client.visualisation.methods.gbrowser.util.SamBamUtils;
+import fi.csc.microarray.client.visualisation.methods.gbrowser.util.TsvSorter;
+import fi.csc.microarray.client.visualisation.methods.gbrowser.util.SamBamUtils.SamBamUtilState;
+import fi.csc.microarray.client.visualisation.methods.gbrowser.util.SamBamUtils.SamBamUtilStateListener;
 import fi.csc.microarray.databeans.DataBean;
 import fi.csc.microarray.databeans.DataManager;
 import fi.csc.microarray.exception.MicroarrayException;
